%AnalyzeGroupData.m
%Created 9/12/18 by A. Bosen
%
%This script loads data for all subjects it can find

%This is needed for the ex-Gauss fit
addpath('.\exgauss estimation'); 

dataDirectories = dir(['Experiment Results' filesep 'NH_A_*']);


crossConditionVariableNames = {'subjectID', 'condition', 'percentCorrect', 'meanRT', 'mu', 'sigma', 'tau'};
crossConditionStatistics = cell2table(cell(0,length(crossConditionVariableNames)), 'VariableNames', crossConditionVariableNames);

for(subjectIndex = 1:length(dataDirectories))
	dataDirectory = [dataDirectories(subjectIndex).folder filesep dataDirectories(subjectIndex).name filesep];
	dataFiles = dir([dataDirectory 'stroopwithcontrolkeyboard_raw*.iqdat']);
	if(~isempty(dataFiles))
		
		allSubjectData = [];
		for(fileIndex = 1:length(dataFiles))
			data = readtable([dataFiles(fileIndex).folder filesep dataFiles(fileIndex).name],'filetype','text');
			if(isempty(allSubjectData))
				allSubjectData = data;
			else
				allSubjectData = [allSubjectData;data];
			end
		end

		congruencyTypes = unique(allSubjectData.values_congruency);
		congruencyTypeNames = {'Congruent', 'Incongruent', 'Neutral'};
		for(congruencyIndex = congruencyTypes')
			conditionRTs = allSubjectData.latency(allSubjectData.values_congruency == congruencyIndex & allSubjectData.correct == 1);
			outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
			allOutliers = [];
			%Low end cutoff is fixed at 200 ms, as in Schmiedek et al. 2007
			outliers = conditionRTs(conditionRTs < 200);
			allOutliers = [allOutliers;outliers];
			conditionRTs(conditionRTs < 200) = [];
			while(any(conditionRTs > outlierCutoff))
				outliers = conditionRTs(conditionRTs > outlierCutoff);
				disp(['RTs labeled as outliers: ' num2str(outliers')]);
				allOutliers = [allOutliers;outliers];
				conditionRTs(conditionRTs > outlierCutoff) = []; 
				outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
			end
			percentCorrect(congruencyIndex) = mean(allSubjectData.correct(allSubjectData.values_congruency == congruencyIndex));
			exGaussParams(congruencyIndex,:) = exgauss_fit(conditionRTs);
			meanRT(congruencyIndex) = geomean(conditionRTs);
		end


		statTable = table(repmat({dataDirectories(subjectIndex).name},length(congruencyTypes),1),...
			congruencyTypeNames',...
			percentCorrect',...
			meanRT',...
			exGaussParams(:,1),...
			exGaussParams(:,2),...
			exGaussParams(:,3),...
			'VariableNames', crossConditionVariableNames);

		%Save results to a single table
		crossConditionStatistics = [crossConditionStatistics; statTable];
	end

end

%Plot the change in each summary statistic across task conditions
subjects = unique(crossConditionStatistics.subjectID);
for(metricIndex = 3:width(crossConditionStatistics))

	figure;
	hold on;
	for(subjectIndex = 1:length(subjects))
		congruentMetric(subjectIndex) = crossConditionStatistics{strcmp('Congruent',crossConditionStatistics.condition) &...
						strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID),metricIndex};
		incongruentMetric(subjectIndex) = crossConditionStatistics{strcmp('Incongruent',crossConditionStatistics.condition) &...
						strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID),metricIndex};
		neutralMetric(subjectIndex) = crossConditionStatistics{strcmp('Neutral',crossConditionStatistics.condition) &...
						strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID),metricIndex};
		plot(1:3, [neutralMetric(subjectIndex) congruentMetric(subjectIndex), incongruentMetric(subjectIndex)],'-','Color',[0.2 0.2 0.2],'LineWidth',1);
	end
	%Thick line for group mean
	plot(1:3, [geomean(neutralMetric) geomean(congruentMetric) geomean(incongruentMetric)],'k-','LineWidth',3);
	signrank(congruentMetric,incongruentMetric)
	if(metricIndex == 4)
		%Special condition to ensure consistency for the mean RT plot across tasks
		axis([0.5 3.5 0 2200]);
	else
		axis([0.5 3.5 0 max(crossConditionStatistics{:,metricIndex})*1.05]);
	end
	ylabel(crossConditionStatistics.Properties.VariableNames(metricIndex));
	set(gca,'FontSize',18);
	set(gcf,'PaperUnits','inches','PaperPosition',[0 0 5.3 4]);
	box off;
	xticks(1:3);
	xticklabels({'Neutral', '\newline Congruent', 'Incongruent'});
	outputFileName = ['.\Figures\Stroop Group Change in ' crossConditionStatistics.Properties.VariableNames{metricIndex} ' Across Listening Conditions'];
	print(outputFileName,'-dpng','-r600');
end
