%AnalyzeGroupData.m
%Created 10/27/17 by A. Bosen
%
%This script loads data for all subjects it can find and plots group averages

%Updated 12/30/2021.  Some of the scores for the serial recall tasks were calculated
%by averaging the proportion of items correct across each list length, which over-weights
%performance on low-list lenghts relative to the preferred score of averaging the total
%number of items recalled across all list lengths. The old calculations are retained for
%comparison, renamed with the 'OldCalculation' suffix to mark the original scores.

dataDirectories = dir('.\Experiment Results\NH_A_*');

crossConditionVariableNames = {'subjectID', 'stimulus', 'condition', 'confusionsIncluded', 'capacity',...
'capacityByPhoneme', 'absolutePercentCorrect', 'proportionalPercentCorrect', 'percentPhonemesCorrect', 'nTrials', 'serialPositionCurve'};

crossConditionStatistics = cell2table(cell(0,length(crossConditionVariableNames)), 'VariableNames', crossConditionVariableNames);

stimuli = {'Digits','CVC Concrete Nouns', 'PRESTO'};
listeningConditions = {'16 Channel Vocoded', '8 Channel Vocoded', '4 Channel Vocoded'};

for(stimulusIndex = 1:length(stimuli))
	for(conditionIndex = 1:length(listeningConditions))

		experimentType = [listeningConditions{conditionIndex} ' ' stimuli{stimulusIndex}];
		
		if(strcmp(stimuli(stimulusIndex),'Digits')) 

			%Get each subject's data, do some processing to get metrics
			for(subjectIndex = 1:length(dataDirectories))
				dataDirectory = [dataDirectories(subjectIndex).folder filesep dataDirectories(subjectIndex).name filesep];
				fileString = [dataDirectory experimentType ' Block*.csv'];
				if(~isempty(dir(fileString)))
					data = LoadSubjectData(fileString);
					data = CalculateDigitTrialStatistics(data);
					summaryStatistics(subjectIndex) = CalculateSummaryStatistics(data);
				end

			end

			spanSizes = sort(unique(data.NumberOfDigits));

			%Pack calculated statistics into a single table for use in subsequent analysis
			statTable = table({dataDirectories.name}',...
					repmat(stimuli(stimulusIndex),length(summaryStatistics),1),...
					repmat(listeningConditions(conditionIndex),length(summaryStatistics),1),...
					zeros(length(summaryStatistics),1),...
					[summaryStatistics.capacity]',...
					[summaryStatistics.capacityByPhoneme]',...
					{summaryStatistics.absolutePercentCorrect}',...
					{summaryStatistics.proportionalPercentCorrect}',...
					{summaryStatistics.percentPhonemesCorrect}',...
					{summaryStatistics.nTrials}',...
					{summaryStatistics.serialPositionCurve}',...
					'VariableNames', crossConditionVariableNames); 

		elseif(strcmp(stimuli(stimulusIndex),'CVC Concrete Nouns'))

			for(subjectIndex = 1:length(dataDirectories))
				dataDirectory = [dataDirectories(subjectIndex).folder filesep dataDirectories(subjectIndex).name filesep];
				fileString = [dataDirectory experimentType ' Block*.csv'];
				if(~isempty(dir(fileString)))
					data = LoadSubjectData(fileString);
					data = CalculateCVCTrialStatistics(data);
					[dataWithConfusions, dataWithoutConfusions] = SplitCVCDataByConfusion(data);
					summaryStatistics(subjectIndex) = CalculateSummaryStatistics(dataWithoutConfusions);
				end

			end

			spanSizes = sort(unique(data.NumberOfWords));

			statTable = table({dataDirectories.name}',...
					repmat(stimuli(stimulusIndex),length(summaryStatistics),1),...
					repmat(listeningConditions(conditionIndex),length(summaryStatistics),1),...
					zeros(length(summaryStatistics),1),...
					[summaryStatistics.capacity]',...
					[summaryStatistics.capacityByPhoneme]',...
					{summaryStatistics.absolutePercentCorrect}',...
					{summaryStatistics.proportionalPercentCorrect}',...
					{summaryStatistics.percentPhonemesCorrect}',...
					{summaryStatistics.nTrials}',...
					{summaryStatistics.serialPositionCurve}',...
					'VariableNames', crossConditionVariableNames); 

		elseif(strcmp(stimuli(stimulusIndex),'PRESTO'))
			
			for(subjectIndex = 1:length(dataDirectories))
				dataDirectory = [dataDirectories(subjectIndex).folder filesep dataDirectories(subjectIndex).name filesep];
				fileString = [dataDirectory experimentType '*.xlsx'];
				if(~isempty(dir(fileString)))
					data = LoadSubjectData(fileString);
					percentCorrect(subjectIndex) = {sum(data.x_Correct) / sum(data.x_Keywords)};
				end
			end

			%While we don't have a dedicated CalculateSummaryStatistics function for PRESTO, we do need some basic
			%metrics, while leaving the undefined variables for PRESETO as nans.
			statTable = table({dataDirectories.name}',...
				repmat(stimuli(stimulusIndex),length(summaryStatistics),1),...
				repmat(listeningConditions(conditionIndex),length(summaryStatistics),1),...
				zeros(length(percentCorrect),1),...
				nan(length(percentCorrect),1),...
				nan(length(percentCorrect),1),...
				repmat({nan},length(percentCorrect),1),...
				percentCorrect',...
				repmat({nan},length(percentCorrect),1),...
				repmat({height(data)},length(percentCorrect),1),...
				mat2cell(nan(length(percentCorrect),1),ones(size(percentCorrect))),...
				'VariableNames', crossConditionVariableNames);
		else
			statTable = [];
		end

		%Save results to a single table
		crossConditionStatistics = [crossConditionStatistics; statTable];

	end
end

%Indices to making slicing the data easier
digitIndex = strcmp('Digits',crossConditionStatistics.stimulus);
wordIndex = strcmp('CVC Concrete Nouns',crossConditionStatistics.stimulus);
PRESTOIndex = strcmp('PRESTO',crossConditionStatistics.stimulus);
confusionsIncludedIndex = crossConditionStatistics.confusionsIncluded == 1;

%Get a list of everyone we found in our experiment results
subjects = unique(crossConditionStatistics.subjectID);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%FIGURE 1. Individual PRESTO performance across vocoder levels
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
PRESTO16ChannelAccuracy = vertcat(crossConditionStatistics.proportionalPercentCorrect{PRESTOIndex &...
       					strcmp('16 Channel Vocoded',crossConditionStatistics.condition)});
PRESTO8ChannelAccuracy = vertcat(crossConditionStatistics.proportionalPercentCorrect{PRESTOIndex &...
       					strcmp('8 Channel Vocoded',crossConditionStatistics.condition)});
PRESTO4ChannelAccuracy = vertcat(crossConditionStatistics.proportionalPercentCorrect{PRESTOIndex &...
       					strcmp('4 Channel Vocoded',crossConditionStatistics.condition)});


figure;
hold on;
for(subjectIndex = 1:length(subjects))
	plot(1:3, [PRESTO16ChannelAccuracy(subjectIndex)...
       			PRESTO8ChannelAccuracy(subjectIndex)...
		       	PRESTO4ChannelAccuracy(subjectIndex) ],...
		       	'-','LineWidth',1,'Color',[0 0 0])
end
axis([0.5 3.5 0 1]);
ylabel('PRESTO Keywords Correct');
xlabel('Spectral Resolution');
set(gca,'FontSize',20);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 7.75 5.5]);
box on;
xticks(1:3);
xticklabels({'16 Channel', '8 Channel', '4 Channel'});
outputFileName = ['.\Figures\Group PRESTO Performance Across Listening Conditions'];
print(outputFileName,'-dpng','-r600');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Figure 1 Analysis. Correlations across conditions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%PCA allows us to consider vocoder level as an ordinal variable. Averaging across conditions gives
%uneven leverage to conditions considering the relationship across spectral resolutions isn't linear.
%Still, as an alternative averaging shouldn't produce results that would be too different from what
%we obtain here, given that loadings are similar across vocoder levels.

disp('PRESTO summary statistics across conditions:');
disp(['   16 Channel Mean: ' num2str(mean(PRESTO16ChannelAccuracy)) ', variance: ' num2str(std(PRESTO16ChannelAccuracy))]);
disp(['    8 Channel Mean: ' num2str(mean(PRESTO8ChannelAccuracy)) ', variance: ' num2str(std(PRESTO8ChannelAccuracy))]);
disp(['    4 Channel Mean: ' num2str(mean(PRESTO4ChannelAccuracy)) ', variance: ' num2str(std(PRESTO4ChannelAccuracy))]);

%Build a single matrix for dimensionality reduction
PRESTOPCAInput = [PRESTO16ChannelAccuracy PRESTO8ChannelAccuracy PRESTO4ChannelAccuracy];
disp('PRESTO Correlation Matrix:');
corr(PRESTOPCAInput) %Inset to figure 1

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Table 1. PRESTO PCA dimensionality reduction
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
normedPRESTOPCAInput = (PRESTOPCAInput - mean(PRESTOPCAInput,'omitnan'))./std(PRESTOPCAInput,'omitnan');
disp('PRESTO PCA Results:');
[PRESTOPCAcoefficients, PRESTOPCAscores, PRESTOPCAvariances, PRESTOPCATSquared, percentVarianceExplained, ~] =  pca(normedPRESTOPCAInput)
PRESTOCompositeScore = PRESTOPCAscores(:,1);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%FIGURE 2. Correlation of WASI and PRESTO
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
WASIresults = readtable('..\EF Tasks\WASI Scores.xlsx');
%This gets only relevant columns and cuts out people who didn't finish both session of the experiment
trimmedWASIresults = WASIresults(cellfun(@(x) any(strcmp(x,subjects)),WASIresults.Subject),[1 8 9 11]);

disp(['WASI PRI      mean: ' num2str(mean(trimmedWASIresults.PRICompositeScore))]);
disp(['               min: ' num2str(min(trimmedWASIresults.PRICompositeScore))]);
disp(['               max: ' num2str(max(trimmedWASIresults.PRICompositeScore))]);
disp(['standard deviation: ' num2str(std(trimmedWASIresults.PRICompositeScore))]);

%16 Channel
figure;
plot(trimmedWASIresults.PRICompositeScore, PRESTO16ChannelAccuracy,'ok','MarkerSize',10);
hold on;
%gmregress can be obtained from:
%http://www.mathworks.com/matlabcentral/fileexchange/27918-gmregress
%Thanks to Trujillo-Ortiz and Hernandez-Walls for writing this.
%We don't use ordinary least squres regression because the measurement uncertainty
%on both axes is about equal, which would result in an underestimate of regression slope
Bregression = gmregress(trimmedWASIresults.PRICompositeScore, PRESTO16ChannelAccuracy);
%We don't plot the line because the trend wasn't significant (see below), but include the
%code here if anyone wants to see it.
%plot([82 128], Bregression(1) + Bregression(2) * [82 128],'k','Linewidth',2);
set(gca,'FontSize',20);
xticks([70:15:130]);
yticks([0:0.25:1]);
xlabel('WASI Perceptual Reasoning Index');
ylabel('16 Channel Accuracy');
axis([68 132 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 7.75 4.5]);
outputFileName = ['.\Figures\WASI vs 16 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[WASIPRESTO16Channelr, WASIPRESTO16ChannelP] = corr(trimmedWASIresults.PRICompositeScore, PRESTO16ChannelAccuracy);
disp('WASI-16 Channel PRESTO Correlation:');
disp(['   r = ' num2str(WASIPRESTO16Channelr) ', P = ' num2str(WASIPRESTO16ChannelP)]);

%8 Channel
figure;
plot(trimmedWASIresults.PRICompositeScore, PRESTO8ChannelAccuracy,'ok','MarkerSize',10);
hold on;
Bregression = gmregress(trimmedWASIresults.PRICompositeScore, PRESTO8ChannelAccuracy);
%We don't plot the line because the trend wasn't significant (see below), but include the
%code here if anyone wants to see it.
%plot([82 128], Bregression(1) + Bregression(2) * [82 128],'k','Linewidth',2);
set(gca,'FontSize',20);
xticks([70:15:130]);
yticks([0:0.25:1]);
xlabel('WASI Perceptual Reasoning Index');
ylabel('8 Channel Accuracy');
axis([68 132 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 7.75 4.5]);
outputFileName = ['.\Figures\WASI vs 8 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[WASIPRESTO8Channelr, WASIPRESTO8ChannelP] = corr(trimmedWASIresults.PRICompositeScore, PRESTO8ChannelAccuracy);
disp('WASI-8 Channel PRESTO Correlation:');
disp(['   r = ' num2str(WASIPRESTO8Channelr) ', P = ' num2str(WASIPRESTO8ChannelP)]);

%4 Channel
figure;
plot(trimmedWASIresults.PRICompositeScore, PRESTO4ChannelAccuracy,'ok','MarkerSize',10);
hold on;
Bregression = gmregress(trimmedWASIresults.PRICompositeScore, PRESTO4ChannelAccuracy);
%We don't plot the line because the trend wasn't significant (see below), but include the
%code here if anyone wants to see it.
%plot([42 124], Bregression(1) + Bregression(2) * [42 124],'k','Linewidth',2);
set(gca,'FontSize',20);
xticks([70:15:130]);
yticks([0:0.25:1]);
xlabel('WASI Perceptual Reasoning Index');
ylabel('4 Channel Accuracy');
axis([68 132 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 7.75 4.5]);
outputFileName = ['.\Figures\WASI vs 4 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[WASIPRESTO4Channelr, WASIPRESTO4ChannelP] = corr(trimmedWASIresults.PRICompositeScore, PRESTO4ChannelAccuracy);
disp('WASI-4 Channel PRESTO Correlation:');
disp(['   r = ' num2str(WASIPRESTO4Channelr) ', P = ' num2str(WASIPRESTO4ChannelP)]);

%Composite
figure;
plot(trimmedWASIresults.PRICompositeScore, PRESTOCompositeScore,'ok','MarkerSize',10);
hold on;
Bregression = gmregress(trimmedWASIresults.PRICompositeScore, PRESTOCompositeScore);
%We don't plot the line because the trend wasn't significant (see below), but include the
%code here if anyone wants to see it.
%plot([82 128], Bregression(1) + Bregression(2) * [82 128],'k','Linewidth',2);
set(gca,'FontSize',20);
xticks([70:15:130]);
yticks([-3:3]);
xlabel('WASI Perceptual Reasoning Index');
ylabel('PRESTO Composite Score');
axis([68 132 -3.95 3.95]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 7.75 4.5]);
outputFileName = ['.\Figures\WASI vs composite PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[WASIPRESTOr, WASIPRESTOP] = corr(trimmedWASIresults.PRICompositeScore, PRESTOCompositeScore);
disp('WASI-PRESTO Composite Correlation:');
disp(['   r = ' num2str(WASIPRESTOr) ', P = ' num2str(WASIPRESTOP)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%FIGURE 3. Serial Span performance across vocoder conditions
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%Plot mean proportional percent correct
for(stimulusIndex = 1:(length(stimuli)-1))
	for(conditionIndex = 1:length(listeningConditions))
		if(strcmp(stimuli(stimulusIndex),'Digits'))
			edgeColor = [0.2 0.2 0.2];
			groupPercentCorrect = vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex & strcmp(listeningConditions(conditionIndex),crossConditionStatistics.condition)});
			spanSizes = 2:9;
		elseif(strcmp(stimuli(stimulusIndex),'CVC Concrete Nouns'))
			edgeColor = [0.6 0.6 0.6];
			groupPercentCorrect = vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex & strcmp(listeningConditions(conditionIndex),crossConditionStatistics.condition) & ~confusionsIncludedIndex});
			spanSizes = 1:6;
		end

		figure;
		plot(spanSizes, groupPercentCorrect,...
			'-','Color',edgeColor,'LineWidth',1);
		hold on;
		plot(spanSizes, mean(groupPercentCorrect),...
			'-','Color',edgeColor-0.2,'LineWidth',4);
		xlabel('List Length (# Items)');
		if(strcmp(stimuli(stimulusIndex),'Digits'))
			ylabel('Digits Correct');
		elseif(strcmp(stimuli(stimulusIndex),'CVC Concrete Nouns'))
			ylabel('Phonemes Correct');
		end
		set(gca,'FontSize',20);
		set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4 3]);
		xticks(1:9);
		yticks(0:0.25:1);
		axis([1 9 0 1]);
		box off;
		outputFileName = ['.\Figures\Group Mean ' stimuli{stimulusIndex} ' ' listeningConditions{conditionIndex} ' Proportional Scoring Psychometric Function'];
		print(outputFileName,'-dpng','-r600');
	end 
end


%Plot digit proportion correct across listening conditions
%The extra mean around these calls is to average across all list lengths
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%NOTE: The old calculation values are the ones reported in the original publication
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Digits16ChannelAccuracyOldCalculation = mean(vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex & strcmp('16 Channel Vocoded',crossConditionStatistics.condition)}),2);
Digits8ChannelAccuracyOldCalculation = mean(vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex & strcmp('8 Channel Vocoded',crossConditionStatistics.condition)}),2);
Digits4ChannelAccuracyOldCalculation = mean(vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex & strcmp('4 Channel Vocoded',crossConditionStatistics.condition)}),2);
Digits16ChannelAccuracy = (vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex & strcmp('16 Channel Vocoded',crossConditionStatistics.condition)}) *(2:9)'*10)/440;
Digits8ChannelAccuracy = (vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex & strcmp('8 Channel Vocoded',crossConditionStatistics.condition)}) *(2:9)'*10)/440;
Digits4ChannelAccuracy = (vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex & strcmp('4 Channel Vocoded',crossConditionStatistics.condition)}) *(2:9)'*10)/440;
figure;
hold on;
for(subjectIndex = 1:length(subjects))
	plot(1:3, [Digits16ChannelAccuracy(subjectIndex)...
			Digits8ChannelAccuracy(subjectIndex)...
			Digits4ChannelAccuracy(subjectIndex)],...
			'-','LineWidth',1,'Color',[0.2 0.2 0.2]) 
end
axis([0.5 3.5 0 1]);
yticks(0:0.25:1);
ylabel('Digits Correct');
set(gca,'FontSize',20);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4 3.5]);
box off;
xticks(1:3);
xticklabels({'16', '8', '4'});
xlabel('Num Channels');
outputFileName = ['.\Figures\Group Mean Digit Proportion Correct Across Listening Conditions'];
print(outputFileName,'-dpng','-r600');

%Plot phoneme proportion correct across listening conditions
Words16ChannelAccuracyOldCalculation = mean(vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex & strcmp('16 Channel Vocoded',crossConditionStatistics.condition)}),2);
Words8ChannelAccuracyOldCalculation = mean(vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex & strcmp('8 Channel Vocoded',crossConditionStatistics.condition)}),2);
Words4ChannelAccuracyOldCalculation = mean(vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex & strcmp('4 Channel Vocoded',crossConditionStatistics.condition)}),2);
Words16ChannelAccuracy = (vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex & strcmp('16 Channel Vocoded',crossConditionStatistics.condition)}) *(3:3:18)'*10)/630;
Words8ChannelAccuracy = (vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex & strcmp('8 Channel Vocoded',crossConditionStatistics.condition)}) *(3:3:18)'*10)/630;
Words4ChannelAccuracy = (vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex & strcmp('4 Channel Vocoded',crossConditionStatistics.condition)}) *(3:3:18)'*10)/630;
figure;
hold on;
for(subjectIndex = 1:length(subjects))
	plot(1:3, [Words16ChannelAccuracy(subjectIndex)...
			Words8ChannelAccuracy(subjectIndex)...
			Words4ChannelAccuracy(subjectIndex)],...
			'-','LineWidth',1,'Color',[0.6 0.6 0.6]) 
end
axis([0.5 3.5 0 1]);
yticks(0:0.25:1);
ylabel('Phonemes Correct');
set(gca,'FontSize',20);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4 3.5]);
box off;
xticks(1:3);
xticklabels({'16', '8', '4'});
xlabel('Num Channels');
outputFileName = ['.\Figures\Group Mean Phoneme Proportion Correct Across Listening Conditions'];
print(outputFileName,'-dpng','-r600');

%Report correlations between old calculations and preferred calculation to demonstrate that they yield very similar estimates of individual differences
disp(['Correlations between old method of calculation proportion correct and preferred method:']);
disp(['   16 Channel Digits: ' num2str(corr(Digits16ChannelAccuracy,Digits16ChannelAccuracyOldCalculation))]);
disp(['    8 Channel Digits: ' num2str(corr(Digits8ChannelAccuracy,Digits8ChannelAccuracyOldCalculation))]);
disp(['    4 Channel Digits: ' num2str(corr(Digits4ChannelAccuracy,Digits4ChannelAccuracyOldCalculation))]);
disp(['    16 Channel Words: ' num2str(corr(Words16ChannelAccuracy,Words16ChannelAccuracyOldCalculation))]);
disp(['     8 Channel Words: ' num2str(corr(Words8ChannelAccuracy,Words8ChannelAccuracyOldCalculation))]);
disp(['     4 Channel Words: ' num2str(corr(Words4ChannelAccuracy,Words4ChannelAccuracyOldCalculation))]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Figure 4. Correlation of Span and PRESTO
%NOTE: The original manuscript reported correlations at Rho, whereas r would be more appropriate
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

%16 Channel Digits
figure;
plot(Digits16ChannelAccuracy, PRESTO16ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(Digits16ChannelAccuracy, PRESTO16ChannelAccuracy);
plot([0.59 0.91], Bregression(1) + Bregression(2) * [0.59 0.91],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([0:0.25:1]);
yticks([0:0.25:1]);
xlabel('16 Channel Digits Correct');
ylabel('16 Channel Accuracy');
axis([0.3 1 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\16 Channel Digit Span vs 16 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[DigitPRESTO16Channelr, DigitPRESTO16ChannelP] = corr(Digits16ChannelAccuracy, PRESTO16ChannelAccuracy);
disp('16 Channel Digit-16 Channel PRESTO Correlation:');
disp(['   r = ' num2str(DigitPRESTO16Channelr) ', P = ' num2str(DigitPRESTO16ChannelP)]);

%8 Channel Digits
figure;
plot(Digits8ChannelAccuracy, PRESTO8ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(Digits8ChannelAccuracy, PRESTO8ChannelAccuracy);
plot([0.56 0.92], Bregression(1) + Bregression(2) * [0.56 0.92],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([0:0.25:1]);
yticks([0:0.25:1]);
xlabel('8 Channel Digits Correct');
ylabel('8 Channel Accuracy');
axis([0.3 1 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\8 Channel Digit Span vs 8 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[DigitPRESTO8Channelr, DigitPRESTO8ChannelP] = corr(Digits8ChannelAccuracy, PRESTO8ChannelAccuracy);
disp('8 Channel Digit-8 Channel PRESTO Correlation:');
disp(['   r = ' num2str(DigitPRESTO8Channelr) ', P = ' num2str(DigitPRESTO8ChannelP)]);

%4 Channel Digits
figure;
plot(Digits4ChannelAccuracy, PRESTO4ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(Digits4ChannelAccuracy, PRESTO4ChannelAccuracy);
plot([0.52 0.9], Bregression(1) + Bregression(2) * [0.52 0.9],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([0:0.25:1]);
yticks([0:0.25:1]);
xlabel('4 Channel Digits Correct');
ylabel('4 Channel Accuracy');
axis([0.3 1 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\4 Channel Digit Span vs 4 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[DigitPRESTO4Channelr, DigitPRESTO4ChannelP] = corr(Digits4ChannelAccuracy, PRESTO4ChannelAccuracy);
disp('4 Channel Digit-4 Channel PRESTO Correlation:');
disp(['   r = ' num2str(DigitPRESTO4Channelr) ', P = ' num2str(DigitPRESTO4ChannelP)]);

%16 Channel Words
figure;
plot(Words16ChannelAccuracy, PRESTO16ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(Words16ChannelAccuracy, PRESTO16ChannelAccuracy);
plot([0.63 0.94], Bregression(1) + Bregression(2) * [0.63 0.94],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([0:0.25:1]);
yticks([0:0.25:1]);
xlabel('16 Channel Phonemes Correct');
ylabel('16 Channel Accuracy');
axis([0.2 1 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\16 Channel Word Span vs 16 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[WordPRESTO16Channelr, WordPRESTO16ChannelP] = corr(Words16ChannelAccuracy, PRESTO16ChannelAccuracy);
disp('16 Channel Word-16 Channel PRESTO Correlation:');
disp(['   r = ' num2str(WordPRESTO16Channelr) ', P = ' num2str(WordPRESTO16ChannelP)]);

%8 Channel Words
figure;
plot(Words8ChannelAccuracy, PRESTO8ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(Words8ChannelAccuracy, PRESTO8ChannelAccuracy);
plot([0.57 0.91], Bregression(1) + Bregression(2) * [0.57 0.91],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([0:0.25:1]);
yticks([0:0.25:1]);
xlabel('8 Channel Phonemes Correct');
ylabel('8 Channel Accuracy');
axis([0.2 1 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\8 Channel Word Span vs 8 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[WordPRESTO8Channelr, WordPRESTO8ChannelP] = corr(Words8ChannelAccuracy, PRESTO8ChannelAccuracy);
disp('8 Channel Word-8 Channel PRESTO Correlation:');
disp(['   r = ' num2str(WordPRESTO8Channelr) ', P = ' num2str(WordPRESTO8ChannelP)]);

%4 Channel Words
figure;
plot(Words4ChannelAccuracy, PRESTO4ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(Words4ChannelAccuracy, PRESTO4ChannelAccuracy);
plot([0.25 0.82], Bregression(1) + Bregression(2) * [0.25 0.82],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([0:0.25:1]);
yticks([0:0.25:1]);
xlabel('4 Channel Phonemes Correct');
ylabel('4 Channel Accuracy');
axis([0.2 1 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\4 Channel Word Span vs 4 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[WordPRESTO4Channelr, WordPRESTO4ChannelP] = corr(Words4ChannelAccuracy, PRESTO4ChannelAccuracy);
disp('4 Channel Word-4 Channel PRESTO Correlation:');
disp(['   r = ' num2str(WordPRESTO4Channelr) ', P = ' num2str(WordPRESTO4ChannelP)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Table 2. Changes in serial span across vocoder conditions, PCA 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
crossConditionStatistics.meanProportionalPercentCorrect(digitIndex) = cellfun(@(x) (x * (2:9)'*10)/440,crossConditionStatistics.proportionalPercentCorrect(digitIndex));
crossConditionStatistics.meanProportionalPercentCorrect(wordIndex) = cellfun(@(x) (x * (1:6)'*10)/210,crossConditionStatistics.proportionalPercentCorrect(wordIndex));
disp('********************************************************************************');
disp('Model for digits')
fitResult = fitlme(crossConditionStatistics(digitIndex,:),'meanProportionalPercentCorrect ~ condition + (1 | subjectID)');
disp(fitResult);

crossConditionStatistics.meanPercentPhonemesCorrect(wordIndex) = cellfun(@(x) (x * (1:6)'*10)/210,crossConditionStatistics.percentPhonemesCorrect(wordIndex));
disp('********************************************************************************');
disp('Model for CVCs')
fitResult = fitlme(crossConditionStatistics(wordIndex,:),'meanPercentPhonemesCorrect ~ condition + (1 | subjectID)');
disp(fitResult);

%PCA across listening conditions for digit and phoneme scores, see if we can separate out their respective contributions
SpanPCAMatrixOldCalculation = [mean(vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex &...
       			strcmp('16 Channel Vocoded',crossConditionStatistics.condition)}),2)...
		mean(vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex &...
			strcmp('8 Channel Vocoded',crossConditionStatistics.condition)}),2)...
		mean(vertcat(crossConditionStatistics.proportionalPercentCorrect{digitIndex &...
			strcmp('4 Channel Vocoded',crossConditionStatistics.condition)}),2)...
		mean(vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex &...
			strcmp('16 Channel Vocoded',crossConditionStatistics.condition)}),2)...
		mean(vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex &...
			strcmp('8 Channel Vocoded',crossConditionStatistics.condition)}),2)...
		mean(vertcat(crossConditionStatistics.percentPhonemesCorrect{wordIndex &...
			strcmp('4 Channel Vocoded',crossConditionStatistics.condition)}),2)];
SpanPCAMatrix = [Digits16ChannelAccuracy Digits8ChannelAccuracy Digits4ChannelAccuracy Words16ChannelAccuracy Words8ChannelAccuracy Words4ChannelAccuracy];
SpanPCAMatrix = (SpanPCAMatrix - mean(SpanPCAMatrix)) ./ std(SpanPCAMatrix);

[Spancoefficients, SpanScores, Spanvariances, SpanTSquared, percentVarianceExplained, ~] = pca(SpanPCAMatrix,'Centered',true)

serialRecallAbility = SpanScores(:,1);
vocoderSensitivity = SpanScores(:,2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%FIGURE 5. Regression Analysis between span PCA components and PRESTO
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%16 Channel Serial Recall Ability
figure;
plot(serialRecallAbility, PRESTO16ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(serialRecallAbility, PRESTO16ChannelAccuracy);
plot([-4.7 3.9], Bregression(1) + Bregression(2) * [-4.7 3.9],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([-5:5]);
yticks([0:0.25:1]);
xlabel('Serial Recall Ability');
ylabel('16 Channel Accuracy');
axis([-4.9 4.9 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\Serial Recall Ability vs 16 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[RecallPRESTO16Channelr, RecallPRESTO16ChannelP] = corr(serialRecallAbility, PRESTO16ChannelAccuracy);
disp('Serial Recall Ability-16 Channel PRESTO Correlation:');
disp(['   r = ' num2str(RecallPRESTO16Channelr) ', P = ' num2str(RecallPRESTO16ChannelP)]);


%8 Channel Serial Recall Ability
figure;
plot(serialRecallAbility, PRESTO8ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(serialRecallAbility, PRESTO8ChannelAccuracy);
plot([-4.7 4], Bregression(1) + Bregression(2) * [-4.7 4],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([-5:5]);
yticks([0:0.25:1]);
xlabel('Serial Recall Ability');
ylabel('8 Channel Accuracy');
axis([-4.9 4.9 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\Serial Recall Ability vs 8 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[RecallPRESTO8Channelr, RecallPRESTO8ChannelP] = corr(serialRecallAbility, PRESTO8ChannelAccuracy);
disp('Serial Recall Ability-8 Channel PRESTO Correlation:');
disp(['   r = ' num2str(RecallPRESTO8Channelr) ', P = ' num2str(RecallPRESTO8ChannelP)]);


%4 Channel Serial Recall Ability
figure;
plot(serialRecallAbility, PRESTO4ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(serialRecallAbility, PRESTO4ChannelAccuracy);
plot([-4.7 4], Bregression(1) + Bregression(2) * [-4.7 4],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([-5:5]);
yticks([0:0.25:1]);
xlabel('Serial Recall Ability');
ylabel('4 Channel Accuracy');
axis([-4.9 4.9 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\Serial Recall Ability vs 4 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[RecallPRESTO4Channelr, RecallPRESTO4ChannelP] = corr(serialRecallAbility, PRESTO4ChannelAccuracy);
disp('Serial Recall Ability-4 Channel PRESTO Correlation:');
disp(['   r = ' num2str(RecallPRESTO4Channelr) ', P = ' num2str(RecallPRESTO4ChannelP)]);


%Composite Serial Recall Ability
figure;
plot(serialRecallAbility, PRESTOCompositeScore,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(serialRecallAbility, PRESTOCompositeScore);
plot([-4.7 3.7], Bregression(1) + Bregression(2) * [-4.7 3.7],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([-5:5]);
yticks([-3:3]);
xlabel('Serial Recall Ability');
ylabel('PRESTO Composite Score');
axis([-4.9 4.9 -3.95 3.95]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\Serial Recall Ability vs PRESTO Composite Score'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[RecallPRESTOCompositer, RecallPRESTOCompositeP] = corr(serialRecallAbility, PRESTOCompositeScore);
disp('Serial Recall Ability-PRESTO Composite Correlation:');
disp(['   r = ' num2str(RecallPRESTOCompositer) ', P = ' num2str(RecallPRESTOCompositeP)]);

%16 Channel Vocoder Sensitivity
figure;
plot(vocoderSensitivity, PRESTO16ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(vocoderSensitivity, PRESTO16ChannelAccuracy);
%plot([-4.5 3.9], Bregression(1) + Bregression(2) * [-4.5 3.9],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([-5:5]);
yticks([0:0.25:1]);
xlabel('Vocoder Sensitivity');
ylabel('16 Channel Accuracy');
axis([-2.2 2.2 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\Vocoder Sensitivity vs 16 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[RecallPRESTO16Channelr, RecallPRESTO16ChannelP] = corr(vocoderSensitivity, PRESTO16ChannelAccuracy);
disp('Vocoder Sensitivity-16 Channel PRESTO Correlation:');
disp(['   r = ' num2str(RecallPRESTO16Channelr) ', P = ' num2str(RecallPRESTO16ChannelP)]);


%8 Channel Vocoder Sensitivity
figure;
plot(vocoderSensitivity, PRESTO8ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(vocoderSensitivity, PRESTO8ChannelAccuracy);
%plot([-4.5 4], Bregression(1) + Bregression(2) * [-4.5 4],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([-5:5]);
yticks([0:0.25:1]);
xlabel('Vocoder Sensitivity');
ylabel('8 Channel Accuracy');
axis([-2.2 2.2 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\Vocoder Sensitivity vs 8 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[RecallPRESTO8Channelr, RecallPRESTO8ChannelP] = corr(vocoderSensitivity, PRESTO8ChannelAccuracy);
disp('Vocoder Sensitivity-8 Channel PRESTO Correlation:');
disp(['   r = ' num2str(RecallPRESTO8Channelr) ', P = ' num2str(RecallPRESTO8ChannelP)]);


%4 Channel Vocoder Sensitivity
figure;
plot(vocoderSensitivity, PRESTO4ChannelAccuracy,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(vocoderSensitivity, PRESTO4ChannelAccuracy);
%plot([-4.5 4], Bregression(1) + Bregression(2) * [-4.5 4],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([-5:5]);
yticks([0:0.25:1]);
xlabel('Vocoder Sensitivity');
ylabel('4 Channel Accuracy');
axis([-2.2 2.2 0 1]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\Vocoder Sensitivity vs 4 channel PRESTO Accuracy'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[RecallPRESTO4Channelr, RecallPRESTO4ChannelP] = corr(vocoderSensitivity, PRESTO4ChannelAccuracy);
disp('Vocoder Sensitivity-4 Channel PRESTO Correlation:');
disp(['   r = ' num2str(RecallPRESTO4Channelr) ', P = ' num2str(RecallPRESTO4ChannelP)]);


%Composite Vocoder Sensitivity
figure;
plot(vocoderSensitivity, PRESTOCompositeScore,'ok','MarkerSize',10);
hold on; 
Bregression = gmregress(vocoderSensitivity, PRESTOCompositeScore);
%plot([-4.5 3.7], Bregression(1) + Bregression(2) * [-4.5 3.7],'k','Linewidth',2);
set(gca,'FontSize',15);
xticks([-5:5]);
yticks([-3:3]);
xlabel('Vocoder Sensitivity');
ylabel('PRESTO Composite Score');
axis([-2.2 2.2 -3.95 3.95]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4.25 4]);
outputFileName = ['.\Figures\Vocoder Sensitivity vs PRESTO Composite Score'];
print(outputFileName,'-dpng','-r600');

%Simple linear correlation
[RecallPRESTOCompositer, RecallPRESTOCompositeP] = corr(vocoderSensitivity, PRESTOCompositeScore);
disp('Vocoder Sensitivity-PRESTO Composite Correlation:');
disp(['   r = ' num2str(RecallPRESTOCompositer) ', P = ' num2str(RecallPRESTOCompositeP)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Figure 5 additional analysis. Correlation between serial recall and WASI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[RecallWASIr, RecallWASIP] = corr(trimmedWASIresults.PRICompositeScore, serialRecallAbility);
disp('Serial Recall Ability-WASI Correlation:');
disp(['   r = ' num2str(RecallWASIr) ', P = ' num2str(RecallWASIP)]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Build a table for use in the attention data analysis
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
spanAndPRESTOTable = table;
spanAndPRESTOTable.Subject = subjects;
spanAndPRESTOTable.PRESTO16Channel = PRESTO16ChannelAccuracy;
spanAndPRESTOTable.PRESTO8Channel = PRESTO8ChannelAccuracy;
spanAndPRESTOTable.PRESTO4Channel = PRESTO4ChannelAccuracy;
spanAndPRESTOTable.PRESTOComposite = PRESTOCompositeScore;
spanAndPRESTOTable.serialRecallAbility = serialRecallAbility;
spanAndPRESTOTable.vocoderSensitivity = vocoderSensitivity;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Below are alternative analyses of the data, which are not reported in the main
%text. Overall, these analysis produce little change in the reported trends,
%which gives us confidence that these trends are not byproducts of specific data
%analysis techniques.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Plot individual memory results and group average performance for each listening condition 
for(stimulusIndex = 1:(length(stimuli)-1))
	for(conditionIndex = 1:length(listeningConditions))
		if(strcmp(stimuli(stimulusIndex),'Digits'))
			edgeColor = [0 1 0];
			groupPercentCorrect = vertcat(crossConditionStatistics.absolutePercentCorrect{digitIndex & strcmp(listeningConditions(conditionIndex),crossConditionStatistics.condition)});
			spanSizes = 2:9;
		elseif(strcmp(stimuli(stimulusIndex),'CVC Concrete Nouns'))
			edgeColor = [1 0 0];
			groupPercentCorrect = vertcat(crossConditionStatistics.absolutePercentCorrect{wordIndex & strcmp(listeningConditions(conditionIndex),crossConditionStatistics.condition) & ~confusionsIncludedIndex});
			spanSizes = 1:6;
		end

		figure;
		plot(spanSizes, groupPercentCorrect,...
			'-','Color',edgeColor,'LineWidth',1);
		hold on;
		plot(spanSizes, mean(groupPercentCorrect),...
			'-','Color',edgeColor,'LineWidth',6);
		xlabel('List Length (# Items)');
		ylabel('Correct List Rate');
		set(gca,'FontSize',20);
		set(gcf,'PaperUnits','inches','PaperPosition',[0 0 5 4]);
		xticks(1:9);
		yticks(0:0.25:1);
		axis([1 9 0 1]);
		box off;
		outputFileName = ['.\Figures\Group Mean ' stimuli{stimulusIndex} ' ' listeningConditions{conditionIndex} ' Absolute Scoring Psychometric Function'];
		print(outputFileName,'-dpng','-r600');
	end 
end


%Plot trends in 50% recall span across listening conditions
figure;
hold on;
for(subjectIndex = 1:length(subjects))
	plot(1:3, [crossConditionStatistics.capacity(digitIndex &...
       					strcmp('16 Channel Vocoded',crossConditionStatistics.condition) &...
				       	strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID))...
			crossConditionStatistics.capacity(digitIndex &...
       					strcmp('8 Channel Vocoded',crossConditionStatistics.condition) &...
				       	strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID))...
			crossConditionStatistics.capacity(digitIndex &...
       					strcmp('4 Channel Vocoded',crossConditionStatistics.condition) &...
				       	strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID))],...
			'-','LineWidth',1,'Color',[0 1 0])
	plot(1:3, [crossConditionStatistics.capacity(wordIndex &...
       					strcmp('16 Channel Vocoded',crossConditionStatistics.condition) &...
				       	strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID))...
			crossConditionStatistics.capacity(wordIndex &...
       					strcmp('8 Channel Vocoded',crossConditionStatistics.condition) &...
				       	strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID))...
			crossConditionStatistics.capacity(wordIndex &...
       					strcmp('4 Channel Vocoded',crossConditionStatistics.condition) &...
				       	strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID))],...
			'-','LineWidth',1,'Color',[1 0 0])
end
axis([0.5 3.5 0 10.25]);
yticks(0:9);
ylabel('50% Correct Recall Length');
set(gca,'FontSize',20);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 6 6]);
box off;
xticks(1:3);
xticklabels({'16 Channel', '8 Channel', '4 Channel'});
outputFileName = ['.\Figures\Group Mean Span Across Listening Conditions'];
print(outputFileName,'-dpng','-r600');

%Show that 50% point estimate and proportional scoring are highly correlated
figure;
hold on;
plot(crossConditionStatistics.meanProportionalPercentCorrect(digitIndex &...
	strcmp('16 Channel Vocoded',crossConditionStatistics.condition)),...
     crossConditionStatistics.capacity(digitIndex &...
	strcmp('16 Channel Vocoded',crossConditionStatistics.condition)),...
'.','MarkerSize',20,'Color',[0 1 0]);
plot(crossConditionStatistics.meanProportionalPercentCorrect(digitIndex &...
	strcmp('8 Channel Vocoded',crossConditionStatistics.condition)),...
     crossConditionStatistics.capacity(digitIndex &...
	strcmp('8 Channel Vocoded',crossConditionStatistics.condition)),...
'.','MarkerSize',20,'Color',[0 0.6 0]);
plot(crossConditionStatistics.meanProportionalPercentCorrect(digitIndex &...
	strcmp('4 Channel Vocoded',crossConditionStatistics.condition)),...
     crossConditionStatistics.capacity(digitIndex &...
	strcmp('4 Channel Vocoded',crossConditionStatistics.condition)),...
'.','MarkerSize',20,'Color',[0 0.2 0]);
axis([0.6 1 4 10.25]);
yticks(0:10);
xticks(0:0.1:1);
ylabel('50% Correct Recall Length');
xlabel('Proportional Correct Scoring');
set(gca,'FontSize',20);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 6 6]);
box off;
outputFileName = ['.\Figures\Digit Span Scoring Comparison'];
print(outputFileName,'-dpng','-r600');

%Instead of PCA, simply average performance across listening conditions, and see which task best predicts PRESTO scores.
averagedResults = table;
averagedResults.Subject = subjects;
averagedResults.digit = mean([crossConditionStatistics.meanProportionalPercentCorrect(digitIndex &...
       					strcmp('16 Channel Vocoded',crossConditionStatistics.condition))...
			crossConditionStatistics.meanProportionalPercentCorrect(digitIndex &...
       					strcmp('8 Channel Vocoded',crossConditionStatistics.condition))...
			crossConditionStatistics.meanProportionalPercentCorrect(digitIndex &...
       					strcmp('4 Channel Vocoded',crossConditionStatistics.condition))],2);
averagedResults.digitZScore = nan(height(averagedResults),1);
averagedResults.digitZScore(~isnan(averagedResults.digit)) = zscore(averagedResults.digit(~isnan(averagedResults.digit)));
averagedResults.word= mean([crossConditionStatistics.meanProportionalPercentCorrect(wordIndex &...
       					strcmp('16 Channel Vocoded',crossConditionStatistics.condition))...
			crossConditionStatistics.meanProportionalPercentCorrect(wordIndex &...
       					strcmp('8 Channel Vocoded',crossConditionStatistics.condition))...
			crossConditionStatistics.meanProportionalPercentCorrect(wordIndex &...
       					strcmp('4 Channel Vocoded',crossConditionStatistics.condition))],2);
averagedResults.wordZScore = nan(height(averagedResults),1);
averagedResults.wordZScore(~isnan(averagedResults.word)) = zscore(averagedResults.word(~isnan(averagedResults.word)));
averagedResults.PRESTO = mean([vertcat(crossConditionStatistics.proportionalPercentCorrect{PRESTOIndex &...
       					strcmp('16 Channel Vocoded',crossConditionStatistics.condition)})...
			vertcat(crossConditionStatistics.proportionalPercentCorrect{PRESTOIndex &...
       					strcmp('8 Channel Vocoded',crossConditionStatistics.condition)})...
			vertcat(crossConditionStatistics.proportionalPercentCorrect{PRESTOIndex&...
       					strcmp('4 Channel Vocoded',crossConditionStatistics.condition)})],2);
averagedResults.PRESTOZScore(~isnan(averagedResults.PRESTO)) = zscore(averagedResults.PRESTO(~isnan(averagedResults.PRESTO)));
disp('********************************************************************************');
disp('Supplemental correlations of average performance across listening conditions');
fitlm(averagedResults,'PRESTOZScore ~ -1 + digitZScore')

fitlm(averagedResults,'PRESTOZScore ~ -1 + digitZScore + wordZScore')

%Show that Word Span is a predictor of PRESTO
figure;
plot(averagedResults.word,averagedResults.PRESTO,'.r','MarkerSize',10);
hold on;
Bregression = gmregress(averagedResults.word,averagedResults.PRESTO);
plot([0 1], Bregression(1) + Bregression(2) * [0 1],'r','Linewidth',2);
xlabel('Average Phonemes Correct');
ylabel('Average PRESTO Score');
axis([0.45 0.95 0.5 0.8]);
xticks(0.4:0.1:1);
set(gca,'FontSize',14);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 3.5 3.5]);
box on;
outputFileName = ['.\Figures\Group PRESTO Correlation with Words Correct'];
print(outputFileName,'-dpng','-r600');

fitlm(averagedResults,'PRESTOZScore ~ -1 + wordZScore')
