%CalculateWordTrialStatistics.m
%
%Created 11/30/17 by A. Bosen
%This function goes through each trial of Word data and calculates the number of phonemes and Words
%that were correct repeated, along with whether the entire trial was correct
%The returned data structure is a modified version of the input, with added columns that include statistics

function [dataWithStatistics, confusionMatrix] = CalculateWordTrialStatistics(data) 

	%Build an index to easily retrieve all the data from a trial
	maxSpanLength = max(data.NumberOfWords);
	%Find the columns labeled 'WordSequence' and 'Response'
	sequenceStartColumn = find(strcmp(data.Properties.VariableNames,'WordSequence'));
	responseStartColumn = find(strcmp(data.Properties.VariableNames,'Response'));
	sequenceIndex = sequenceStartColumn:sequenceStartColumn+maxSpanLength-1;
	responseIndex = responseStartColumn:responseStartColumn+maxSpanLength-1;

	%Some subjects never responded with a full list of items,
	%so we need to add '' to the last column(s)
	if(max(responseIndex) > size(data,2))
		dummyColumn = cell(size(data,1),max(responseIndex) - size(data,2));
		dummyColumn(:) = {''};
		data = [data array2table(dummyColumn)];
	end 

	%Not all 128 positions will be used, but keeping the indices in ASCII avoids having to
	%create and keep track of a mapping from indices to characters.
	confusionMatrix = zeros(128);

	%Go through the data for each trial, calculate summary results of each trial
	for(trialIndex = 1:size(data,1))
		sequence = data{trialIndex,sequenceIndex};
		response = data{trialIndex,responseIndex};
		%Shorten the sequence to NumberOfWords
		if(data.NumberOfWords(trialIndex) ~= sum(cellfun(@(x) ~isempty(x),data{trialIndex,sequenceIndex})))
			error(['In trial ' num2str(data.TrialNumber(trialIndex)) ', NumberOfWords does not match number of Words in sequence']);
		end
		sequence = sequence(1:data.NumberOfWords(trialIndex));

		%Cut blanks from the response
		response = response(cellfun(@(x) ~isempty(x),response));

		%Append blank spaces to the response to make it equal in length to the sequence
		response = [response repmat({' '},1,length(sequence)-length(response))];
		
		totalPhonemesCorrect = [];
		totalWordsCorrect = [];
		for(sequenceWordIndex = 1:data.NumberOfWords(trialIndex))
			%For the response, we remove leading and trailing whitespace with the assumption that it was a typo
			responseWord = strtrim(response{sequenceWordIndex});
			sequenceWord = sequence{sequenceWordIndex};

			%Compare phonemes in the response and sequence Words
			if(length(responseWord) < length(sequenceWord))
				%If the response is shorter than the sequence Word, then compare whatever we have
				%and label the missing phonemes incorrect
				phonemesCorrectInThisWord = (responseWord(1:length(responseWord)) == sequenceWord(1:length(responseWord))) * 1;
				phonemesCorrectInThisWord = [phonemesCorrectInThisWord zeros(1,length(sequenceWord) - length(responseWord))];
				WordCorrect = 0;
			elseif(length(responseWord) > length(sequenceWord))
				%If the response is longer than the sequence Word, compare the phonemes in the sequence
				%Word, but consider the whole Word incorrect.
				phonemesCorrectInThisWord = (responseWord(1:length(sequenceWord)) == sequenceWord(1:length(sequenceWord))) * 1;
				WordCorrect = 0;
			else
				%If the response and sequence are equal length, compare them and evaluate if the Word is correct
				phonemesCorrectInThisWord = (responseWord == sequenceWord) * 1;
				WordCorrect = all(phonemesCorrectInThisWord == 1) * 1;
			end

			%Check if any of the target phonemes are subject to confusion
			%We only do this if there's a chance the whole Word could be correct
			%if we account for confusions, otherwise we don't really care.
			%TODO: figure out if there's a way to do this as a vector operation rather than in a loop
			%TODO: also figure out a way to store this rule as a data structure, rather than a long if statement
			if(length(sequenceWord) == length(responseWord))
				for(phonemeIndex = 1:length(sequenceWord))
					%These confusions all occurred more than 5% of the time
					%Vowels
					if((sequenceWord(phonemeIndex) == '@' && responseWord(phonemeIndex) == 'a') ...
					|| (sequenceWord(phonemeIndex) == 'E' && any(responseWord(phonemeIndex) == ['@' '^' 'a' 'o'])) ...
					|| (sequenceWord(phonemeIndex) == 'a' && any(responseWord(phonemeIndex) == ['@' 'u'])) ...
					|| (sequenceWord(phonemeIndex) == 'e' && any(responseWord(phonemeIndex) == ['i' 'o'])) ...
					|| (sequenceWord(phonemeIndex) == 'i' && responseWord(phonemeIndex) == 'e') ...
					|| (sequenceWord(phonemeIndex) == 'o' && any(responseWord(phonemeIndex) == ['R' 'a' 'u' 'e'])) ...
					|| (sequenceWord(phonemeIndex) == 'u' && responseWord(phonemeIndex) == 'i') ...
					... %Consonants
					|| (sequenceWord(phonemeIndex) == 'C' && any(responseWord(phonemeIndex) == ['S' 'f' 'h'])) ...
					|| (sequenceWord(phonemeIndex) == 'S' && any(responseWord(phonemeIndex) == ['C' 'f' 's'])) ...
					|| (sequenceWord(phonemeIndex) == 'd' && responseWord(phonemeIndex) == 'v') ...
					|| (sequenceWord(phonemeIndex) == 'f' && any(responseWord(phonemeIndex) == ['d' 'p' 'v'])) ...
					|| (sequenceWord(phonemeIndex) == 'h' && any(responseWord(phonemeIndex) == ['C' 'm' 'p'])) ...
					|| (sequenceWord(phonemeIndex) == 'm' && any(responseWord(phonemeIndex) == ['n'])) ...
					|| (sequenceWord(phonemeIndex) == 'p' && any(responseWord(phonemeIndex) == ['f' 'h'])) ...
					|| (sequenceWord(phonemeIndex) == 's' && any(responseWord(phonemeIndex) == ['C' 'S'])) ...
					|| (sequenceWord(phonemeIndex) == 'v' && any(responseWord(phonemeIndex) == ['d' 'm' 'z'])) ...
					|| (sequenceWord(phonemeIndex) == 'w' && any(responseWord(phonemeIndex) == ['r' 'h'])) ...
					|| (sequenceWord(phonemeIndex) == 'z' && any(responseWord(phonemeIndex) == ['p' 'v'])) ...
					)
						phonemesCorrectInThisWord(phonemeIndex) = 0.5;
					end

					%Add the phonemes to the confusion matrix
					confusionMatrix(uint8(sequenceWord(phonemeIndex)),uint8(responseWord(phonemeIndex))) = confusionMatrix(uint8(sequenceWord(phonemeIndex)),uint8(responseWord(phonemeIndex))) + 1; 
				end

				%If all phonemes were a mix of correct or confused, we'll consider this Word a partial success
				if(all(phonemesCorrectInThisWord > 0) & ~all(phonemesCorrectInThisWord == 1))
					WordCorrect = 0.5;
				end
			end
			totalPhonemesCorrect = [totalPhonemesCorrect phonemesCorrectInThisWord];
			totalWordsCorrect = [totalWordsCorrect WordCorrect];
		end
		data.phonemesCorrect(trialIndex) = {totalPhonemesCorrect};
		data.WordsCorrect(trialIndex) = {totalWordsCorrect};
		%To get the whole trial right, the number of response Words must match the number of target Words
		if(data.NumberOfWords(trialIndex) == length(response))
			data.correctResponse(trialIndex) = all(data.WordsCorrect{trialIndex} == 1) * 1;
			%This trial is considered a partial success if all Words were either correct or partial successes
			all(data.WordsCorrect{trialIndex} >= 0.5);
			if(~data.correctResponse(trialIndex) && all(data.WordsCorrect{trialIndex} >= 0.5))
				data.correctResponse(trialIndex) = 0.5;
			end
		else
			data.correctResponse(trialIndex) = 0;
		end
	end
	dataWithStatistics = data;

end 
