%CalculateSummaryStatistics.m
%
%Created 11/30./17 by A. Bosen
%
%This function takes a data table with trial statistics and calculates summary statistics over all trials.
function [summaryStatistics] = CalculateSummaryStatistics(data)

	%Check if this is digit or CVC data and get the corresponding fields 
	%Really this should probably be refactored so that the data fields are renamed elsewhere
	if(any(strcmp('NumberOfDigits',fieldnames(data))))
		data.NumberOfItems = data.NumberOfDigits;
		data.itemsCorrect = data.digitsCorrect;
		data.itemPositions = data.digitPositions;
	elseif(any(strcmp('NumberOfWords',fieldnames(data))))
		data.NumberOfItems = data.NumberOfWords;
		data.itemsCorrect = data.WordsCorrect;
	end

	summaryStatistics = struct;
	%Calculate summary statistics over all trials
	spanSizes = sort(unique(data.NumberOfItems));
	serialPositionCurve = cell(length(spanSizes),1);
	transpositionGradient = cell(length(spanSizes),1);
	for(spanSizeIndex = 1:length(spanSizes))
		trialsOfThisSizeIndex = data.NumberOfItems == spanSizes(spanSizeIndex);
		nTrials(spanSizeIndex) = sum(trialsOfThisSizeIndex);
		serialPositionCurve(spanSizeIndex) = {mean(ceil(vertcat(data.itemsCorrect{logical(trialsOfThisSizeIndex)'})))};
		%Absolute scoring, value is 1 if all items are correct, 0 otherwise. See Unsworth and Engle 2006 for comparison of scoring methods
		[absolutePercentCorrect(spanSizeIndex) absoluteConfInt(spanSizeIndex,:)] = binofit(sum(ceil(data.correctResponse(trialsOfThisSizeIndex))),...
										 sum(trialsOfThisSizeIndex));
		%proportional scoring, value is the the proportion of items recalled in the correct place
		[proportionalPercentCorrect(spanSizeIndex) proportionalConfInt(spanSizeIndex,:)] = ...
	       		binofit(sum(cellfun(@(x) sum(ceil(x)),data.itemsCorrect(trialsOfThisSizeIndex))),...
				sum(trialsOfThisSizeIndex) * spanSizes(spanSizeIndex));
		if(any(strcmp('NumberOfDigits',fieldnames(data))))
			%Don't calculate TGs for CVCs because that's really hard to do and should be a separate program
			transpositionGradient(spanSizeIndex) = {mean(cat(3,data.itemPositions{trialsOfThisSizeIndex}),3)};
		elseif(any(strcmp('NumberOfWords',fieldnames(data))))
			%Also score CVCs by number of phonemes correct
			percentPhonemesCorrect(spanSizeIndex) = binofit(sum(ceil([data.phonemesCorrect{trialsOfThisSizeIndex}])),...
									 length([data.phonemesCorrect{trialsOfThisSizeIndex}]));
		end
	end

	[logisticRegression, logisticDeviation, regressionStats] = glmfit(spanSizes,[(nTrials .* absolutePercentCorrect)' nTrials'],'binomial');
	capacity = logisticRegression(1)/logisticRegression(2) * -1; %To obtain the 50% crossing point

	if(any(strcmp('NumberOfWords',fieldnames(data))))
		summaryStatistics.percentPhonemesCorrect = percentPhonemesCorrect;
		logisticRegressionByPhoneme = glmfit(spanSizes,[(nTrials .* percentPhonemesCorrect)' nTrials'],'binomial');
		summaryStatistics.logisticRegressionByPhoneme = logisticRegressionByPhoneme;
		capacityByPhoneme = logisticRegressionByPhoneme(1)/logisticRegressionByPhoneme(2) * -1; %To obtain the 50% crossing point
		summaryStatistics.capacityByPhoneme = capacityByPhoneme;
	else
		summaryStatistics.percentPhonemesCorrect = nan;
		summaryStatistics.logisticRegressionByPhoneme = nan;
		summaryStatistics.capacityByPhoneme = nan;
	end

	summaryStatistics.absolutePercentCorrect = absolutePercentCorrect;
	summaryStatistics.proportionalPercentCorrect = proportionalPercentCorrect;
	summaryStatistics.nTrials = nTrials;	
	summaryStatistics.absolutePercentCorrectConfInt = absoluteConfInt;
	summaryStatistics.proportionalPercentCorrectConfInt = proportionalConfInt;
	summaryStatistics.logisticRegression = logisticRegression;
	summaryStatistics.logisticDeviation = logisticDeviation;
	summaryStatistics.regressionStats = regressionStats;
	summaryStatistics.capacity = capacity;
	summaryStatistics.serialPositionCurve = serialPositionCurve;
	summaryStatistics.transpositionGradient = transpositionGradient;


end
